@@ -3,7 +3,7 @@ context("h5 : write data")
 # for use travis in parallel
 Sys.unsetenv("R_TESTS")
 
-if(requireNamespace("rhdf5")){
+if(requireNamespace("rhdf5") & .runThisTest){
   tpDir2 <- gsub("[\\]", "/", tpDir)
   tptpDir <- file.path(tpDir2, "/tpDir")
   
@@ -19,16 +19,21 @@ if(requireNamespace("rhdf5")){
   if(DoPar)
   {
     test_that("h5 : overwrite + alldata + multi-thread", {
+      skip_on_cran()
       writeAntaresH5(path = tptpDir, overwrite = TRUE, allData = TRUE, 
                      timeSteps = "annual", writeAllSimulations = TRUE, 
                      nbCores = 2, opts = optsG)
+      filesTptpDir<-dir(tptpDir)
+      expect_true(TRUE %in% grepl("h5", filesTptpDir))
       
     })
   }
   
   test_that("h5 : overwrite + removeVirtualAreas", {
     writeAntaresH5(path = tptpDir, overwrite = TRUE, opts = optsG, timeSteps = "hourly",removeVirtualAreas = TRUE,
-                   storageFlexibility = "a")
+                   storageFlexibility = "a", nbCores = 1)
+    filesTptpDir<-dir(tptpDir)
+    expect_true(TRUE %in% grepl("h5", filesTptpDir))
     
   })
   
