@@ -41,7 +41,7 @@ sapply(studyPathS, function(studyPath){
                            hourly = 24 * 7 * nweeks,
                            daily = 7 * nweeks,
                            weekly = nweeks,
-                           monthly = 1,
+                           monthly = nmonths,
                            annual = 1)
     
     test_that(sprintf("one can import %s output", timeStep), {
